#!/usr/bin/env python

import sys
import traceback

from PySide.QtGui import QApplication, QMessageBox
from LTgui import LTMainWindow

if __name__ == '__main__':
    app = QApplication(sys.argv)

    try:
        w = LTMainWindow()
        w.show()
        w.setupMenu()
        w.setupScreen()
        w.loadData()

        app.exec_()
    except Exception, e:
        QMessageBox.critical(None, 'Error', traceback.format_exc())
        
    sys.exit()
